package com.smcic.api.admin.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.smcic.api.admin.dto.NamePageDTO;
import com.smcic.api.admin.entity.Organ;
import com.smcic.api.admin.entity.Users;
import com.smcic.api.admin.mapper.OrganMapper;
import com.smcic.api.admin.service.IOrganService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.stream.Collectors;

/**
 * <p>
 * 机构表 服务实现类
 * </p>
 *
 * @author syj
 * @since 2023-11-16
 */
@Service
public class OrganServiceImpl extends ServiceImpl<OrganMapper, Organ> implements IOrganService {

    @Resource
    private UsersServiceImpl usersService;

    public void create (Organ organ) {
        save(organ);
    }

    public Page<Organ> organList (NamePageDTO namePageDTO) {
        LambdaQueryWrapper<Organ> lambdaQueryWrapper = Wrappers.lambdaQuery();
        Page<Organ> organPage = baseMapper.selectPage(new Page<>(namePageDTO.getPage(), namePageDTO.getPageSize()),
                lambdaQueryWrapper.eq(Organ::getPid, 0).orderByDesc(Organ::getOrganId));

        if(organPage.getTotal() > 0) {
            organPage.setRecords(organPage.getRecords().stream().peek(organ -> {
                organ.setChildren(lambdaQuery().eq(Organ::getPid, organ.getOrganId()).list());
            }).collect(Collectors.toList()));
        }
        return organPage;
    }

    public void modify(Organ organ) {
        updateById(organ);
    }

    public void delete(Long organId) {
        if(usersService.lambdaQuery().eq(Users::getOrganId, organId).exists()) {
            throw new RuntimeException("该机构下存在用户,不能删除");
        }
        removeById(organId);
    }
}
